File

Enum File 

#[repr(u8)]
pub enum File { One = 0, Two = 1, Three = 2, Four = 3, Five = 4, Six = 5, Seven = 6, Eight = 7, Nine = 8, }
A file (column) on a shogi board.

Variants



One = 0

File One



Two = 1

File Two



Three = 2

File Three



Four = 3

File Four



Five = 4

File Five



Six = 5

File Six



Seven = 6

File Seven



Eight = 7

File Eight



Nine = 8

File Nine

Implementations

Source

impl File

pub const NUM: usize = 9usize

The number of File variants.

pub const ALL: [Self; 9]

An array of all File variants.

pub const fn try_index(index: usize) -> Option<Self>

Checked version of File::index.

pub fn index(index: usize) -> Self

Convert an index to a File.

Panics

Panic if the index is out of bounds.

pub const fn index_const(index: usize) -> Self

const version of File::index.

Panics

Panic if the index is out of bounds.

pub const fn to_index(self) -> usize

Cast File as usize.

Source

impl File

pub const fn flip(self) -> Self

Flip the file horizontally around the central file File::Five.

This mirrors the file in the central file. It maps File::One to File::Nine, and vice-versa, and similar for all other files.

Examples
assert_eq!(File::Five.flip(), File::Five);
assert_eq!(File::One.flip(), File::Nine);
pub const fn bitboard(self) -> BitBoard

Get a bitboard with all squares on this file set.

File 1 is the east-most file board diagrams.

Examples
assert_eq!(File::Eight.bitboard(), bitboard! {
    . X . . . . . . .
    . X . . . . . . .
    . X . . . . . . .
    . X . . . . . . .
    . X . . . . . . .
    . X . . . . . . .
    . X . . . . . . .
    . X . . . . . . .
    . X . . . . . . .
});
pub const fn west(self) -> BitBoard

Get a bitboard with all squares to the West of this file set.

Examples
use haitaka_types::*;
assert_eq!(File::Nine.west(), BitBoard::EMPTY);
assert_eq!(File::Eight.west(), File::Nine.bitboard());
assert_eq!(File::Two.west(), bitboard!{
    X X X X X X X . .
    X X X X X X X . .
    X X X X X X X . .
    X X X X X X X . .
    X X X X X X X . .
    X X X X X X X . .
    X X X X X X X . .
    X X X X X X X . .
    X X X X X X X . .
});
pub const fn east(self) -> BitBoard

Get a bitboard with all squares to the East of this file set.

Examples
use haitaka_types::*;
assert_eq!(File::One.east(), BitBoard::EMPTY);
assert_eq!(File::Two.east(), File::One.bitboard());
assert_eq!(File::Seven.east(), bitboard!{
    . . . X X X X X X
    . . . X X X X X X
    . . . X X X X X X
    . . . X X X X X X
    . . . X X X X X X
    . . . X X X X X X
    . . . X X X X X X
    . . . X X X X X X
    . . . X X X X X X
});